.. _workflow_chapter:

========
Workflow
========

In CMF, the "workflow tool" allows developers to design state machines
which imply transition between content states.

:app:`Pyramid` itself has no such concept, but the
:term:`repoze.workflow` package provides a simple state machine
implementation that can act as a barebones workflow tool.  See its
documentation for more information.

